Slips, trips and falls are prevented. | OiRA

Help

1. Preparació
2. Implicació
3. Identificació + Avaluació
4. Pla d'acció
   1. 1.1.1 Slips, trips and falls are not prevented.
   2. 1.1.2 Collisions, bumps, and jamming are not prevented.
   3. 1.1.4 Exposure to noise is neither prevented nor controlled.
   4. 1.1.6 Exposure to biological substances is neither prevented nor controlled
   5. Ω.1 The entrance floor is often wet
   6. Title of the first custom risk
   7. This is another custom risk added by the user
   - Actuar
5. Informe
6. Grau d’emplenament 57%

   You've completed 57% of the risk assessment. When you've completed 85% of the risk assessment, you will be eligible for a certificate.

   With this certificate, you can apply for a reduction on your company's insurance rates. Learn more about the benefits…

## Slips, trips and falls are prevented.

Aquest és un risc de prioritat
.

A significant number of occupational accidents are related to moving around the client company’s premises, either inside or outside the buildings (e.g. static surveillance, rounds and surveillance patrols). These are...

#### Més informació sobre aquest risc.

Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Vestibulum tortor quam, feugiat vitae, ultricies eget, tempor sit amet, ante. Donec eu libero sit amet quam egestas semper. Aenean ultricies mi vitae est. Mauris placerat eleifend leo.

- Lorem ipsum dolor sit amet, consectetuer adipiscing elit.
- Aliquam tincidunt mauris eu risus.
- Vestibulum auctor dapibus neque.

## Mesures pre-establertes

Seleccioni una o més de les mesures comunes facilitades.

Visual inspection of work areas. Afegir Provide good equipment Afegir Inform the private security guards Afegir The private security guard reports correctly and immediately disfunction of electricity, gas and water systems. Afegir

## Mesura implementada: Visual inspection of work areas

#### Description

    Make sure a visual inspection of work areas is carried out in order to identify the potential hazards of falls and slips. Check that the anti-fall fittings and protective measures are present and in good condition."
        expertise: "Contrary to popular belief, Lorem Ipsum is not simply random text.

    Beware of the following possible hazards.

    - Slippery slopes
    - Falling pianos
    - Angry queens

    It has roots in a piece of classical Latin literature from 45 BC, making it over 2000 years old.

## Visual inspection of work areas.

Remove

#### Description

Make sure a visual inspection of work areas is carried out in order to identify the potential hazards of falls and slips. Check that the anti-fall fittings and protective measures are present and in good condition.

#### Expertise

Contrary to popular belief, Lorem Ipsum is not simply random text. - Protective measures It has roots in a piece of classical Latin literature from 45 BC, making it over 2000 years old.

Qui n'és responsable? Appoint someone in your company to be responsible for the implementation of this measure. This person will have the authority to take the steps described in the Plan and/or the responsibility to ensure that they are carried out. Pressupost Although some measures do not cost any money, most do. The measures should therefore be budgeted for; include them in the annual budget round if necessary. Inici de la planificació Final de la planificació

## Provide good equipment

Remove

#### Description

#### Expertise

Qui n'és responsable? Appoint someone in your company to be responsible for the implementation of this measure. This person will have the authority to take the steps described in the Plan and/or the responsibility to ensure that they are carried out. Pressupost Although some measures do not cost any money, most do. The measures should therefore be budgeted for; include them in the annual budget round if necessary. Inici de la planificació Final de la planificació

## Inform the private security guards

Remove

#### Description

#### Expertise

Qui n'és responsable? Appoint someone in your company to be responsible for the implementation of this measure. This person will have the authority to take the steps described in the Plan and/or the responsibility to ensure that they are carried out. Pressupost Although some measures do not cost any money, most do. The measures should therefore be budgeted for; include them in the annual budget round if necessary. Inici de la planificació Final de la planificació

## The private security guard reports correctly and immediately disfunction of electricity, gas and water systems.

Remove

#### Description

#### Expertise

Qui n'és responsable? Appoint someone in your company to be responsible for the implementation of this measure. This person will have the authority to take the steps described in the Plan and/or the responsibility to ensure that they are carried out. Pressupost Although some measures do not cost any money, most do. The measures should therefore be budgeted for; include them in the annual budget round if necessary. Inici de la planificació Final de la planificació

Scroll to top
Back

## action-plan-action.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More